@@ -19,6 +19,7 @@ from GameSentenceMiner.util.model import AnkiCard
 from GameSentenceMiner.util.text_log import get_all_lines, get_text_event, get_mined_line, lines_match
 from GameSentenceMiner.obs import get_current_game
 from GameSentenceMiner.web import texthooking_page
+import re
 
 # Global variables to track state
 previous_note_ids = set()
@@ -161,6 +162,35 @@ def get_initial_card_info(last_note: AnkiCard, selected_lines):
     game_line = get_text_event(last_note)
     sentences = []
     sentences_text = ''
+    
+    # TODO: REMOVE THIS, I DON'T THINK IT'S NEEDED
+    if get_config().wip.overlay_websocket_send:
+        sentence_in_anki = last_note.get_field(get_config().anki.sentence_field).replace("\n", "").replace("\r", "").strip()
+        if lines_match(game_line.text, remove_html_and_cloze_tags(sentence_in_anki)):
+            logger.info("Found matching line in Anki, Preserving HTML and fix spacing!")
+            if "<b>" in sentence_in_anki:
+                text_inside_bold = re.findall(r'<b>(.*?)</b>', sentence_in_anki)
+                logger.info(text_inside_bold)
+                if text_inside_bold:
+                    text = text_inside_bold[0].replace(" ", "").replace('\n', '').strip()
+                    note['fields'][get_config().anki.sentence_field] = game_line.text.replace(text_inside_bold[0], f"<b>{text}</b>")
+                    logger.info(f"Preserved bold Tag for Sentence: {note['fields'][get_config().anki.sentence_field]}")
+            if "<i>" in sentence_in_anki:
+                text_inside_italic = re.findall(r'<i>(.*?)</i>', sentence_in_anki)
+                if text_inside_italic:
+                    text = text_inside_italic[0].replace(" ", "").replace('\n', '').strip()
+                    note['fields'][get_config().anki.sentence_field] = game_line.text.replace(text_inside_italic[0], f"<i>{text}</i>")
+                    logger.info(f"Preserved italic Tag for Sentence: {note['fields'][get_config().anki.sentence_field]}")
+            if "<u>" in sentence_in_anki:
+                text_inside_underline = re.findall(r'<u>(.*?)</u>', sentence_in_anki)
+                if text_inside_underline:
+                    text = text_inside_underline[0].replace(" ", "").replace('\n', '').strip()
+                    note['fields'][get_config().anki.sentence_field] = game_line.text.replace(text_inside_underline[0], f"<u>{text}</u>")
+                    logger.info(f"Preserved underline Tag for Sentence: {note['fields'][get_config().anki.sentence_field]}")
+            
+            if get_config().anki.sentence_field not in note['fields']:
+                logger.info("No HTML tags found to preserve, just fixing spacing")
+                note['fields'][get_config().anki.sentence_field] = game_line.text
     if selected_lines:
         try:
             sentence_in_anki = last_note.get_field(get_config().anki.sentence_field)
