@@ -9,13 +9,14 @@ from typing import Dict, Any, List, Tuple
 from GameSentenceMiner.util.electron_config import get_ocr_language
 
 if get_config().wip.overlay_websocket_send:
-    from GameSentenceMiner.owocr.owocr.ocr import GoogleLens, OneOCR, get_regex
+    try: 
+        from GameSentenceMiner.owocr.owocr.ocr import GoogleLens, OneOCR, get_regex
+        oneocr = OneOCR()
+        lens = GoogleLens()
+    except ImportError:
+        pass
 from GameSentenceMiner.obs import *
 
-if get_config().wip.overlay_websocket_send:
-    oneocr = OneOCR()
-    lens = GoogleLens()
-
 
 def _convert_box_to_pixels_v2(
     bbox_data: Dict[str, float], 
@@ -314,7 +315,7 @@ async def get_full_screenshot() -> Image.Image | None:
             else:
                 monitors = [monitors[0]]
             monitor = monitors[get_config().wip.monitor_to_capture]
-            img = get_screenshot_PIL(compression=100, img_format='jpg')
+            img = get_screenshot_PIL(compression=90, img_format='jpg')
             # Put the image over a transparent background without stretching
             new_img = Image.new("RGBA", (monitor['width'], monitor['height']), (0, 0, 0, 0))
             # Calculate coordinates to center img horizontally and vertically
